===============================
Skyscanner Python SDK
===============================

.. image:: https://img.shields.io/travis/ardydedase/skyscanner.svg
        :target: https://travis-ci.org/ardydedase/skyscanner

.. image:: https://img.shields.io/pypi/v/skyscanner.svg
        :target: https://pypi.python.org/pypi/skyscanner


Skyscanner Python SDK

* Free software: BSD license
* Documentation: https://skyscanner.readthedocs.org.

Features
--------

* TODO
